@@ -24,6 +24,7 @@
 #include "gameview.h"
 
 #include <QCheckBox>
+#include <QDockWidget>
 #include <QLabel>
 #include <QPushButton>
 #include <QLineEdit>
@@ -45,17 +46,22 @@
 #include "dialogs/scoredlg.h"
 #include "dialogs/fleetdlg.h"
 
+#include "view/standingswidget.h"
+
 #include <cmath>
 
 /*********************************************************************
  Game Board
 *********************************************************************/
 
-GameView::GameView( QWidget *parent, Game *game )
+GameView::GameView(QWidget *parent, Game *game, QDockWidget *messagesDock, QDockWidget *standingsDock)
   : QWidget( parent ),
+    m_msgWidgetLastTurn(0),
+    m_messagesDock(messagesDock),
+    m_standingsDock(standingsDock),
     m_game( game ),
     m_queueMessages(false),
-    m_messageQueue(), 
+    m_messageQueue(),
     m_showInformations(false),
     m_initCompleted( false ),
     m_cleanupNeeded( false ),
@@ -68,19 +74,19 @@ GameView::GameView( QWidget *parent, Game *game )
 
     QColor col(Qt::green);
     QPalette palette;
-    palette.setColorGroup( QPalette::Active,   Qt::white,    Qt::black, 
-                           col.light(),        col.dark(),   col,
-                           col.dark(75),       col.dark(75), col.dark(),
+    palette.setColorGroup( QPalette::Active,    Qt::white,          Qt::black,
+                           col.lighter(),       col.darker(),       col,
+                           col.lighter(125),    col.lighter(125),   col.darker(),
                            Qt::black );
-    palette.setColorGroup( QPalette::Inactive, Qt::white,    Qt::black,
-                           col.light(),        col.dark(),   col,
-                           col.dark(75),       col.dark(75), col.dark(), 
+    palette.setColorGroup( QPalette::Inactive,  Qt::white,          Qt::black,
+                           col.lighter(),       col.darker(),       col,
+                           col.lighter(125),    col.lighter(125),   col.darker(),
                            Qt::black );
-    palette.setColorGroup( QPalette::Disabled, Qt::white,    QColor(Qt::darkGray).darker(),
-                           col.light(),        col.dark(),   col,
-                           col.darker(150),    col.dark(75), Qt::black,
+    palette.setColorGroup( QPalette::Disabled,  Qt::white,          QColor(Qt::darkGray).darker(),
+                           col.lighter(),       col.darker(),       col,
+                           col.darker(150),     col.lighter(125),   Qt::black,
                            Qt::black );
-    
+
     blackPal.setColor( QPalette::Base, Qt::black );
     blackPal.setColor( QPalette::Window, Qt::black );
     blackPal.setColor( QPalette::Button, QColor(Qt::darkGray).darker() );
@@ -96,13 +102,16 @@ GameView::GameView( QWidget *parent, Game *game )
     m_mapWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_mapWidget->setFrameShape(QFrame::NoFrame);
 
-    m_msgWidget = new QTextEdit( this );
-    m_msgWidget->setMaximumHeight(75);
+    m_msgWidget = new QTextEdit();
     m_msgWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_msgWidget->setReadOnly(true);
     m_msgWidget->setPalette( blackPal );
     m_msgWidget->setAutoFillBackground( true );
-    m_msgWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+
+    m_messagesDock->setWidget(m_msgWidget);
+
+    m_standingsWidget = new StandingsWidget(0);
+    m_standingsDock->setWidget(m_standingsWidget);
 
     m_gameMessage = new QLabel( this );
     m_gameMessage->setPalette( palette );
@@ -144,10 +153,9 @@ GameView::GameView( QWidget *parent, Game *game )
     topLineLayout->addWidget( m_standingOrder, 1 );
     topLineLayout->addWidget( m_shipCountEdit, 1 );
     topLineLayout->addWidget( m_endTurnBtn, 1 );
-    
+
     mainLayout->addLayout( topLineLayout );
     mainLayout->addWidget( m_mapWidget );
-    mainLayout->addWidget( m_msgWidget );
 
     //**********************************************************************
     // Set up signal/slot connections
@@ -248,6 +256,20 @@ GameView::keyPressEvent( QKeyEvent *e )
 //************************************************************************
 // Game engine/state machine
 //************************************************************************
+
+/**
+ * Prepare the turn for a local player by updating the informational widgets.
+ */
+
+void
+GameView::turnPreparation()
+{
+    m_standingsWidget->update(m_game->players());
+
+    turn();
+}
+
+
 void
 GameView::turn()
 {
@@ -280,9 +302,8 @@ GameView::turn()
             m_shipCountEdit->setText( QString() );
             m_standingOrder->setEnabled(false);
             m_standingOrder->setCheckState(Qt::Unchecked);
-            m_endTurnBtn->setEnabled( true );
             m_mapScene->unselectPlanet();
-            m_gameMessage->setText( i18n("<qt>%1: Select source planet...</qt>", m_game->currentPlayer()->coloredName()) );
+            m_gameMessage->setText( i18n("%1: Select source planet...", m_game->currentPlayer()->coloredName()) );
             setFocus();
         }
 
@@ -298,9 +319,8 @@ GameView::turn()
         } else {
             m_shipCountEdit->setEnabled(false);
             m_standingOrder->setEnabled(false);
-            m_endTurnBtn->setEnabled( false );
             m_mapScene->selectPlanet(sourcePlanet);
-            m_gameMessage->setText( i18n("<qt>%1: Select destination planet...</qt>", m_game->currentPlayer()->coloredName()) );
+            m_gameMessage->setText( i18n("%1: Select destination planet...", m_game->currentPlayer()->coloredName()) );
             setFocus();
         }
 
@@ -316,7 +336,6 @@ GameView::turn()
 
             m_shipCountEdit->setEnabled(false);
             m_standingOrder->setEnabled(false);
-            m_endTurnBtn->setEnabled( true );
 
             m_guiState = NONE;
             turn();
@@ -330,8 +349,6 @@ GameView::turn()
             m_standingOrder->setEnabled(true);
             m_shipCountEdit->setFocus();
 
-            m_endTurnBtn->setEnabled( false );
-
             m_mapScene->unselectPlanet();
         }
 
@@ -345,7 +362,6 @@ GameView::turn()
             turn();
         } else {
             m_shipCountEdit->setEnabled(false);
-            m_endTurnBtn->setEnabled( true );
             m_mapScene->unselectPlanet();
 
             m_gameMessage->setText( i18n("Ruler: Select starting planet.") );
@@ -375,7 +391,6 @@ GameView::turn()
         } else {
             m_gameMessage->setText( i18n("Ruler: Select ending planet.") );
             m_shipCountEdit->setEnabled(false);
-            m_endTurnBtn->setEnabled( false );
             m_mapScene->selectPlanet(sourcePlanet);
 
             setFocus();
@@ -386,6 +401,8 @@ GameView::turn()
         break;
     }
 
+    m_endTurnBtn->setEnabled(m_guiState == SOURCE_PLANET);
+
     emit newGUIState( m_guiState );
 }
 
@@ -418,11 +435,17 @@ GameView::gameMsg(const KLocalizedString &msg, Player *player, Planet *planet,
        plainMsg = plainMsg.subs(planet->name());
     }
 
-    m_msgWidget->append("<qt><font color=\"white\">"
+    if (m_msgWidgetLastTurn < m_game->turnCounter()) {
+        m_msgWidgetLastTurn = m_game->turnCounter();
+
+        m_msgWidget->append("<font color=\"gray\">"
                         + i18n("Turn %1:", m_game->turnCounter())
-                        + "</font> <font color=\"" + color + "\">"
-                        + colorMsg.toString()+"</font></qt>");
-    m_msgWidget->moveCursor( QTextCursor::End );
+                        + "</font>");
+    }
+
+    m_msgWidget->append("- <font color=\"" + color + "\">"
+                        + colorMsg.toString()+"</font>");
+    m_msgWidget->moveCursor(QTextCursor::End);
 
     if (isHumanInvolved) {
         if ( m_queueMessages ) {
@@ -478,7 +501,7 @@ GameView::startNewGame()
 
         LocalPlayer *local = qobject_cast<LocalPlayer*>(player);
         if (local)
-            connect(local, SIGNAL(canPlay()), this, SLOT(turn()));
+            connect(local, SIGNAL(canPlay()), this, SLOT(turnPreparation()));
     }
 
     connect(m_game, SIGNAL(finished()), this, SLOT(gameOver()));
@@ -492,11 +515,11 @@ GameView::startNewGame()
 
     // Set up the base GUI for a new game.
     m_msgWidget->clear();
-    m_shipCountEdit->show();
+    m_msgWidgetLastTurn = 0;
     m_shipCountEdit->setEnabled(false);
     m_initCompleted = true;
 
-    //call GameView::gameOver now if needed happens if the game ends immiedently after starting.
+    //call GameView::gameOver now if needed happens if the game ends immediately after starting.
     if(m_cleanupNeeded)
         gameOver();
 }
@@ -528,11 +551,23 @@ GameView::shutdownGame()
 void
 GameView::gameOver()
 {
-    if(m_initCompleted){
+    if (m_initCompleted) {
         kDebug() << "Game over";
-        ScoreDlg *scoreDlg = new ScoreDlg( this, i18n("Final Standings"),
-                                            m_game->players() );
+
+        /**
+         * @todo This is an attempt to remove duplicate information from screen.
+         * It is not a final solution, but only the best we came up with. The
+         * problem is that the messages cannot be seen anymore, so the player
+         * cannot check what happened last. Furthermore, this sudden change of
+         * the GUI setup can be confusing for players.
+         */
+
+        m_messagesDock->hide();
+        m_standingsDock->hide();
+
+        ScoreDlg *scoreDlg = new ScoreDlg(this, i18n("Final Standings"), m_game->players());
         scoreDlg->exec();
+        scoreDlg->deleteLater();
 
         cleanupGame();
     }
@@ -540,17 +575,14 @@ GameView::gameOver()
         m_cleanupNeeded = true;
 }
 
+
 void
 GameView::cleanupGame()
 {
     m_mapScene->clearMap();
     m_game->stop();
-    
-    m_shipCountEdit->hide();
-    m_endTurnBtn->setEnabled( false );
 
-    m_gameMessage->hide();
-    m_endTurnBtn->hide();
+    m_endTurnBtn->setEnabled( false );
 
     changeGameView();
     m_guiState = NONE;
@@ -636,22 +668,26 @@ GameView::newShipCount()
 void
 GameView::changeGameView()
 {
-    kDebug() << "Calling GameView::changeGameView" << m_game->isRunning();
-    if( m_game->isRunning()) {
-        m_msgWidget->show();
-        m_mapWidget->show();
-        m_gameMessage->show();
-        m_endTurnBtn->show();
-        m_shipCountEdit->show();
-        m_splashScreen->hide();
-    } else {
-        m_mapWidget->hide();
-        m_msgWidget->hide();
-        m_gameMessage->hide();
-        m_endTurnBtn->hide();
-        m_shipCountEdit->hide();
-        m_splashScreen->show();
+    bool isRunning = m_game->isRunning();
+
+    kDebug() << "Calling GameView::changeGameView" << isRunning;
+
+    m_messagesDock->setVisible(isRunning);
+
+    if (!isRunning) {
+
+        // Only hide the standings dock if the game is not running, but do not
+        // automatically show it as soon as the game is running.
+
+        m_standingsDock->hide();
     }
+
+    m_mapWidget->setVisible(isRunning);
+    m_gameMessage->setVisible(isRunning);
+    m_standingOrder->setVisible(isRunning);
+    m_shipCountEdit->setVisible(isRunning);
+    m_endTurnBtn->setVisible(isRunning);
+    m_splashScreen->setVisible(!isRunning); // negation
 }
 
 
@@ -692,14 +728,6 @@ GameView::measureDistance()
     }
 }
 
-void
-GameView::showScores()
-{
-    ScoreDlg *scoreDlg = new ScoreDlg( this, i18n("Current Standings"),
-                                       m_game->players() );
-    scoreDlg->exec();
-    scoreDlg->deleteLater();
-}
 
 void
 GameView::showFleets()
