@@ -19,16 +19,19 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
+
 #ifndef KONQUEST_MAINWIN_H
 #define KONQUEST_MAINWIN_H
 
-
+#include <kaction.h>
 #include <kxmlguiwindow.h>
 
 #include "game.h"
 #include "gameview.h"
 
 class QAction;
+class QDockWidget;
+
 
 class MainWindow : public KXmlGuiWindow
 {
@@ -43,10 +46,13 @@ public:
 private:
     void setupActions();
     void setupGameView();
+    void setupGUI();
 
 private slots:
     void guiStateChange( GUIState );
     void startNewGame();
+    void updateMessagesActionSlot();
+    void updateStandingsActionSlot();
 
 private:
     // Widgets
@@ -55,11 +61,16 @@ private:
     QLabel     *m_statusBarText;
 
     // Actions
-    QAction  *m_endTurnAction;
+    KAction  *m_endTurnAction;
+    KAction  *m_messagesAction;
+    KAction  *m_standingsAction;
+
     QAction  *m_endGameAction;
     QAction  *m_measureAction;
-    QAction  *m_standingAction;
     QAction  *m_fleetAction;
+
+    QDockWidget *m_messagesDock;
+    QDockWidget *m_standingsDock;
 };
 
 #endif // KONQUEST_MAINWIN_H
