@@ -28,10 +28,6 @@ LocalPlayer::LocalPlayer(Game *game, const QString &newName, const QColor &color
 {
 }
 
-bool LocalPlayer::isAiPlayer()
-{
-    return false;
-}
 
 void LocalPlayer::play()
 {
@@ -39,6 +35,7 @@ void LocalPlayer::play()
     emit(canPlay());
 }
 
+
 void LocalPlayer::done()
 {
     kDebug() << name() << "::done";
